# Source Code Has Moved

The code in this directory has been moved to the `socialmapper` package structure.

Please use the modules from the `socialmapper` package instead. This directory is kept
only for backward compatibility and will be removed in a future version. 